
```eval_rst
.. automodule:: nbcelltests
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: nbcelltests.extension
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: nbcelltests.define
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: nbcelltests.lint
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: nbcelltests.tests
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: nbcelltests.shared
   :members:
   :undoc-members:
   :show-inheritance:

```